@@ -10,22 +10,22 @@ import platform
 import random
 import json
 import sys
-from voxelbotutils.cogs.utils.shard_manager import ShardManager
 
 import aiohttp
 import toml
 import discord
 from discord.ext import commands
 from discord.abc import Messageable
+import upgradechat
 
 from .custom_context import Context
 from .database import DatabaseConnection
 from .redis import RedisConnection
 from .statsd import StatsdConnection
 from .analytics_log_handler import AnalyticsLogHandler
-from .upgrade_chat import UpgradeChat
 from .interactions.components import MessageComponents
 from .models import ComponentMessage, ComponentWebhookMessage
+from .shard_manager import ShardManagerClient
 from . import interactions
 from .. import all_packages as all_vfl_package_names
 
@@ -124,9 +124,6 @@ class MinimalBot(commands.AutoShardedBot):
         async def enable_components_msg_prop(message):
             return await message.edit(components=message.components.enable_components())
 
-        # def create_message_prop(state, *args, **kwargs):
-        #     return ComponentMessage(state=state, *args, **kwargs)
-
         Messageable.send = send_button_msg_prop
         discord.message.MessageFlags.ephemeral = discord.flags.flag_value(lambda _: 64)
         discord.message.MessageFlags.VALID_FLAGS.update({"ephemeral": 64})
@@ -149,14 +146,12 @@ class MinimalBot(commands.AutoShardedBot):
 
         discord.PartialMessage.edit = edit_button_msg_prop
 
-        # discord.Message = ComponentMessage
-        # discord.WebhookMessage = ComponentWebhookMessage
-
-        # ConnectionState.create_message = create_message_prop
-
     async def get_application_id(self) -> int:
         """
         Get the bot's application client ID.
+
+        Returns:
+            int: The bot's application ID.
         """
 
         if self.application_id:
@@ -231,7 +226,10 @@ class MinimalBot(commands.AutoShardedBot):
         Add a global slash command for the bot.
 
         Args:
-            command (interactions.ApplicationCommand): The command that you want to add.
+            command (voxelbotutils.ApplicationCommand): The command that you want to add.
+
+        Returns:
+            voxelbotutils.ApplicationCommand: The updated command instance using the returned API data.
         """
 
         application_id = await self.get_application_id()
@@ -249,7 +247,10 @@ class MinimalBot(commands.AutoShardedBot):
 
         Args:
             guild (discord.Guild): The guild you want to add the command to.
-            command (interactions.ApplicationCommand): The command you want to add.
+            command (voxelbotutils.ApplicationCommand): The command you want to add.
+
+        Returns:
+            voxelbotutils.ApplicationCommand: The updated command instance using the returned API data.
         """
 
         application_id = await self.get_application_id()
@@ -266,8 +267,12 @@ class MinimalBot(commands.AutoShardedBot):
         Bulk add a global slash command for the bot.
 
         Args:
-            commands (typing.List[interactions.ApplicationCommand]): The list of commands
+            commands (typing.List[voxelbotutils.ApplicationCommand]): The list of commands
                 you want to add.
+
+        Returns:
+            typing.List[voxelbotutils.ApplicationCommand]: The updated command instances
+                using the returned API data.
         """
 
         application_id = await self.get_application_id()
@@ -285,8 +290,12 @@ class MinimalBot(commands.AutoShardedBot):
 
         Args:
             guild (discord.Guild): The guild you want to add the command to.
-            commands (typing.List[interactions.ApplicationCommand]): The list of commands
+            commands (typing.List[voxelbotutils.ApplicationCommand]): The list of commands
                 you want to add.
+
+        Returns:
+            typing.List[voxelbotutils.ApplicationCommand]: The updated command instances
+                using the returned API data.
         """
 
         application_id = await self.get_application_id()
@@ -302,7 +311,11 @@ class MinimalBot(commands.AutoShardedBot):
         Add a global slash command for the bot.
 
         Returns:
-            typing.List[interactions.ApplicationCommand]: A list of commands that have been added.
+            typing.List[voxelbotutils.ApplicationCommand]: A list of commands that have been added.
+
+        Returns:
+            typing.List[voxelbotutils.ApplicationCommand]: The command instances
+                that were previously added for the application.
         """
 
         application_id = await self.get_application_id()
@@ -321,7 +334,8 @@ class MinimalBot(commands.AutoShardedBot):
             guild (discord.Guild): The guild you want to get commands for.
 
         Returns:
-            typing.List[interactions.ApplicationCommand]: A list of commands that have been added.
+            typing.List[voxelbotutils.ApplicationCommand]: The command instances
+                that were previously added for the application.
         """
 
         application_id = await self.get_application_id()
@@ -337,7 +351,8 @@ class MinimalBot(commands.AutoShardedBot):
         Remove a global slash command for the bot.
 
         Args:
-            command (interactions.ApplicationCommand): The command that you want to remove.
+            command (voxelbotutils.ApplicationCommand): The command that you want to remove. A command
+                ID is required for this to work.
         """
 
         application_id = await self.get_application_id()
@@ -354,7 +369,8 @@ class MinimalBot(commands.AutoShardedBot):
 
         Args:
             guild (discord.Guild): The guild that you want to remove the command on.
-            command (interactions.ApplicationCommand): The command that you want to remove.
+            command (interactions.ApplicationCommand): The command that you want to remove. A command
+                ID is required for this to work.
         """
 
         application_id = await self.get_application_id()
@@ -674,7 +690,7 @@ class MinimalBot(commands.AutoShardedBot):
 
     async def _wait_for_button_message(self, message, *, check=None, timeout=None):
         """
-        Wait for an interaction on a button.
+        Wait for an interaction on a button. Deprecated.
 
         :meta private:
         """
@@ -711,7 +727,7 @@ class Bot(MinimalBot):
         user_agent (str): The user agent that the bot should use for web requests as set in the
             :attr:`config file<BotConfig.user_agent>`. This isn't used automatically anywhere,
             so it just here as a provided convenience.
-        upgrade_chat (UpgradeChat): An UpgradeChat connector instance using the oauth information
+        upgrade_chat (upgradechat.UpgradeChat): An UpgradeChat connector instance using the oauth information
             provided in your :class:`config file<BotConfig.upgrade_chat>`.
         clean_prefix (str): The default prefix for the bot.
         owner_ids (typing.List[int]): A list of the owners from the :attr:`config file<BotConfig.owners>`.
@@ -774,19 +790,13 @@ class Bot(MinimalBot):
 
         # Allow database connections like this
         self.database: DatabaseConnection = DatabaseConnection
-        self.database.logger = self.logger.getChild('database')
 
         # Allow redis connections like this
         self.redis: RedisConnection = RedisConnection
-        self.redis.logger = self.logger.getChild('redis')
 
         # Allow Statsd connections like this
         self.stats: StatsdConnection = StatsdConnection
         self.stats.config = self.config.get('statsd', {})
-        self.stats.logger = self.logger.getChild('statsd')
-
-        # Shard manager time
-        self.shard_manager = ShardManager()  # We don't care about the max concurrency so we're gonna leave that as default
 
         # Gently add an UpgradeChat wrapper here - added as a property method so we can create a new instance if
         # the config is reloaded
@@ -794,6 +804,7 @@ class Bot(MinimalBot):
 
         # Store the startup method so I can see if it completed successfully
         self.startup_method = None
+        self.shard_manager = None
 
         # Regardless of whether we start statsd or not, I want to add the log handler
         handler = AnalyticsLogHandler(self)
@@ -815,7 +826,7 @@ class Bot(MinimalBot):
         try:
             await self._startup()
         except Exception as e:
-            self.logger.error(e)
+            self.logger.error(e, exc_info=True)
             exit(1)
 
     async def _startup(self):
@@ -975,12 +986,15 @@ class Bot(MinimalBot):
         ))
 
     @property
-    def upgrade_chat(self):
+    def upgrade_chat(self) -> upgradechat.UpgradeChat:
         """:meta private:"""
 
         if self._upgrade_chat:
             return self._upgrade_chat
-        self._upgrade_chat = UpgradeChat(self.config["upgrade_chat"]["client_id"], self.config["upgrade_chat"]["client_secret"])
+        self._upgrade_chat = upgradechat.UpgradeChat(
+            self.config["upgrade_chat"]["client_id"],
+            self.config["upgrade_chat"]["client_secret"],
+        )
         return self._upgrade_chat
 
     async def get_user_topgg_vote(self, user_id: int) -> bool:
@@ -1082,7 +1096,7 @@ class Bot(MinimalBot):
 
         # See if we want to make this as a task or not
         if wait is False:
-            return self.loop.create_task(self.add_delete_button(
+            return self.loop.create_task(self.add_delete_reaction(
                 message=message, valid_users=valid_users, delete=delete, timeout=timeout, wait=True,
             ))
 
@@ -1302,6 +1316,9 @@ class Bot(MinimalBot):
     async def start(self, token: str = None, *args, **kwargs):
         """:meta private:"""
 
+        # Say we're starting
+        self.logger.info(f"Starting bot with {self.shard_count} shards")
+
         # See if we should run the startup method
         if self.config.get('database', {}).get('enabled', False):
             self.logger.info("Running startup method")
@@ -1313,13 +1330,19 @@ class Bot(MinimalBot):
         async with aiohttp.ClientSession() as session:
             async with session.get("https://discord.com/api/v9/gateway/bot", headers={"Authorization": f"Bot {self.config['token']}"}) as r:
                 data = await r.json()
-        recommended_shard_count = data['shards']
-        self.logger.info(f"Recommended shard count for this bot: {recommended_shard_count}")
-        if recommended_shard_count / 2 > self.shard_count:
-            self.logger.warning((
-                f"The shard count for this bot ({self.shard_count}) is significantly "
-                f"lower than the recommended number {recommended_shard_count}."
-            ))
+        recommended_shard_count = None
+        try:
+            recommended_shard_count = data['shards']
+            self.logger.info(f"Recommended shard count for this bot: {recommended_shard_count}")
+            self.logger.info(f"Max concurrency for this bot: {data['session_start_limit']['max_concurrency']}")
+        except KeyError:
+            self.logger.info("Recommended shard count for this bot could not be retrieved")
+        else:
+            if recommended_shard_count / 2 > self.shard_count:
+                self.logger.warning((
+                    f"The shard count for this bot ({self.shard_count}) is significantly "
+                    f"lower than the recommended number {recommended_shard_count}"
+                ))
 
         # And run the original
         self.logger.info("Running original D.py start method")
@@ -1430,25 +1453,38 @@ class Bot(MinimalBot):
     async def launch_shard(self, gateway, shard_id: int, *, initial: bool = False):
         """
         Ask the shard manager if we're allowed to launch.
+
+        :meta private:
         """
 
-        redis_config = self.config.get('redis', {})
-        shard_manager_enabled = redis_config.get('shard_manager_enabled', True) and redis_config.get('enabled', True)
+        # See if the shard manager is enabled
+        shard_manager_config = self.config.get('shard_manager', {})
+        shard_manager_enabled = shard_manager_config.get('enabled', False)
 
-        if shard_manager_enabled:
-            await self.shard_manager.ask_to_connect(shard_id)
+        # It isn't so Dpy can just do its thang
+        if not shard_manager_enabled:
+            return await super().launch_shard(gateway, shard_id, initial=initial)
+
+        # Get the host and port to connect to
+        host = shard_manager_config.get('host', '127.0.0.1')
+        port = shard_manager_config.get('port', 8888)
+
+        # Connect using our shard manager
+        shard_manager = await ShardManagerClient.open_connection(host, port)
+        await shard_manager.ask_to_connect(shard_id)
         await super().launch_shard(gateway, shard_id, initial=initial)
-        if shard_manager_enabled:
-            await self.shard_manager.done_connecting(shard_id)
+        await shard_manager.done_connecting(shard_id)
 
     async def launch_shards(self):
         """
         Launch all of the shards using the shard manager.
+
+        :meta private:
         """
 
         # If we don't have redis, let's just ignore the shard manager
-        redis_config = self.config.get('redis', {})
-        if not (redis_config.get('shard_manager_enabled', False) or redis_config.get('enabled', False)):
+        shard_manager_enabled = self.config.get('shard_manager', {}).get('enabled', False)
+        if not shard_manager_enabled:
             return await super().launch_shards()
 
         # Get the gateway
@@ -1464,17 +1500,8 @@ class Bot(MinimalBot):
         shard_ids = self.shard_ids or range(self.shard_count)
         self._connection.shard_ids = shard_ids
 
-        # Set up our shard manager
-        shard_launch_tasks = []
-        self._shard_launch_listener = self.loop.create_task(self.shard_manager.channel_message_listener())
-        shard_manager_timeout = 10
-        try:
-            await asyncio.wait_for(self.shard_manager.pong_received.wait(), timeout=shard_manager_timeout)
-        except asyncio.TimeoutError:
-            self.logger.critical(f"The shard manager for this bot did not respond within {shard_manager_timeout} seconds.")
-            exit(1)
-
         # Connect each shard
+        shard_launch_tasks = []
         for shard_id in shard_ids:
             initial = shard_id == shard_ids[0]
             shard_launch_tasks.append(self.loop.create_task(self.launch_shard(gateway, shard_id, initial=initial)))
@@ -1486,13 +1513,27 @@ class Bot(MinimalBot):
         self._connection.shards_launched.set()
 
     async def connect(self, *, reconnect=True):
+        """
+        A version of connect that uses the shard manager.
+
+        :meta private:
+        """
+
         self._reconnect = reconnect
         await self.launch_shards()
 
-        redis_config = self.config.get('redis', {})
-        shard_manager_enabled = redis_config.get('shard_manager_enabled', True) and redis_config.get('enabled', True)
+        shard_manager_config = self.config.get('shard_manager', {})
+        shard_manager_enabled = shard_manager_config.get('enabled', True)
+        host = shard_manager_config.get('host', '127.0.0.1')
+        port = shard_manager_config.get('port', 8888)
         queue = self._AutoShardedClient__queue  # I'm sorry Danny
 
+        # Make a shard manager instance if we need to
+        async def get_shard_manager():
+            if not shard_manager_enabled:
+                return
+            return await ShardManagerClient.open_connection(host, port)
+
         while not self.is_closed():
             item = await queue.get()
             if item.type == discord.shard.EventType.close:
@@ -1504,11 +1545,12 @@ class Bot(MinimalBot):
                         raise discord.errors.PrivilegedIntentsRequired(item.shard.id) from None
                 return
             elif item.type == discord.shard.EventType.identify:
+                shard_manager = await get_shard_manager()
                 if shard_manager_enabled:
-                    await self.shard_manager.ask_to_connect(item.shard.id, priority=True)  # Let's assign reidentifies a higher priority
+                    await shard_manager.ask_to_connect(item.shard.id, priority=True)  # Let's assign reidentifies a higher priority
                 await item.shard.reidentify(item.error)
                 if shard_manager_enabled:
-                    await self.shard_manager.done_connecting(item.shard.id)
+                    await shard_manager.done_connecting(item.shard.id)
             elif item.type == discord.shard.EventType.resume:
                 await item.shard.reidentify(item.error)
             elif item.type == discord.shard.EventType.reconnect:
