@@ -5,6 +5,14 @@ import discord
 
 
 class DataLocation(enum.Enum):
+    """
+    A defined location for your bot to store information.
+
+    Attributes:
+        GUILD: If the information you want to store is guild-based.
+        USER: If the information you want to store is user-based.
+    """
+
     GUILD = enum.auto()
     USER = enum.auto()
 
@@ -12,7 +20,7 @@ class DataLocation(enum.Enum):
 class MenuCallbacks(object):
 
     @staticmethod
-    def is_discord_object(item) -> bool:
+    def _is_discord_object(item) -> bool:
         return isinstance(
             item,
             (
@@ -29,6 +37,16 @@ class MenuCallbacks(object):
     def set_table_column(cls, data_location: DataLocation, table_name: str, column_name: str):
         """
         Returns a wrapper that updates the guild settings table for the bot's database.
+
+        Args:
+            data_location (voxelbotutils.menus.DataLocation): The location of the content to be stored.
+            table_name (str): The name of the table that you want to store the data in.
+            column_name (str): The name of the column that should be set.
+
+        Returns:
+            typing.Callable[[discord.ext.commands.Context, typing.List[typing.Any]]]: An async wrapper method
+                that does the actual work of adding data to your database. It takes the context object from
+                the menu, and the list of returned converted arguments.
         """
 
         async def wrapper(ctx, data: list):
@@ -37,7 +55,7 @@ class MenuCallbacks(object):
                 "guild_id" if data_location == DataLocation.GUILD else "user_id" if data_location == DataLocation.USER else None,
                 column_name
             )
-            data = [i.id if cls.is_discord_object(i) else i for i in data]
+            data = [i.id if cls._is_discord_object(i) else i for i in data]
             async with ctx.bot.database() as db:
                 await db(
                     sql,
@@ -48,14 +66,25 @@ class MenuCallbacks(object):
         return wrapper
 
     @classmethod
-    def set_cache_from_key(cls, data_location: DataLocation, *settings_path):
+    def set_cache_from_key(cls, data_location: DataLocation, *settings_path: str):
         """
         Returns a wrapper that changes the :attr:`voxelbotutils.Bot.guild_settings` internal cache.
+
+        Args:
+            data_location (voxelbotutils.menus.DataLocation): The location of the content to be stored.
+            *settings_path (str): The path of keys in your cache dictionary to get to the location desired.
+                The last key in the settings path should be the primary key that the converted data gets
+                added as.
+
+        Returns:
+            typing.Callable[[discord.ext.commands.Context, typing.List[typing.Any]]]: A wrapper method
+                that does the actual work of adding data to your cache. It takes the context object from
+                the menu, and the list of returned converted arguments.
         """
 
         def wrapper(ctx, data: list):
             value = data[0]  # If we're here we definitely should only have one datapoint
-            if cls.is_discord_object(value):
+            if cls._is_discord_object(value):
                 value = value.id
             if data_location == DataLocation.GUILD:
                 d = ctx.bot.guild_settings[ctx.guild.id]
@@ -68,16 +97,27 @@ class MenuCallbacks(object):
         return wrapper
 
     @classmethod
-    def set_cache_from_keypair(cls, data_location: DataLocation, *settings_path):
+    def set_cache_from_keypair(cls, data_location: DataLocation, *settings_path: str):
         """
         Returns a wrapper that changes the :attr:`voxelbotutils.Bot.guild_settings` internal cache.
+
+        Args:
+            data_location (voxelbotutils.menus.DataLocation): The location of the content to be stored.
+            *settings_path (str): The path of keys in your cache dictionary to get to the location desired.
+                This method assumes that the data given includes both a key and a value, and the settings
+                path leads to the *dictionary* that the data should be cached into.
+
+        Returns:
+            typing.Callable[[discord.ext.commands.Context, typing.List[typing.Any]]]: A wrapper method
+                that does the actual work of adding data to your cache. It takes the context object from
+                the menu, and the list of returned converted arguments.
         """
 
         def wrapper(ctx, data: list):
             key, value = data  # Two datapoints now; that's very sexy
-            if cls.is_discord_object(key):
+            if cls._is_discord_object(key):
                 key = key.id
-            if cls.is_discord_object(value):
+            if cls._is_discord_object(value):
                 value = value.id
             if data_location == DataLocation.GUILD:
                 d = ctx.bot.guild_settings[ctx.guild.id]
@@ -89,37 +129,28 @@ class MenuCallbacks(object):
 
         return wrapper
 
-    @classmethod
-    def set_iterable_dict_cache(cls, data_location: DataLocation, *settings_path):
-        """
-        Returns a wrapper that changes the :attr:`voxelbotutils.Bot.guild_settings` internal cache.
-        """
-
-        def wrapper(ctx, data: list):
-            key, value = data  # Two datapoints now; that's very sexy
-            if cls.is_discord_object(key):
-                key = key.id
-            if cls.is_discord_object(value):
-                value = value.id
-            if data_location == DataLocation.GUILD:
-                d = ctx.bot.guild_settings[ctx.guild.id]
-            elif data_location == DataLocation.USER:
-                d = ctx.bot.user_settings[ctx.author.id]
-            for i in settings_path:
-                d = d.setdefault(i, dict())
-            d[key] = value
-
-        return wrapper
+    set_iterable_dict_cache = set_cache_from_keypair  # Just for consistency of method names
 
     @classmethod
     def set_iterable_list_cache(cls, data_location: DataLocation, *settings_path):
         """
         Returns a wrapper that changes the :attr:`voxelbotutils.Bot.guild_settings` internal cache.
+
+        Args:
+            data_location (voxelbotutils.menus.DataLocation): The location of the content to be stored.
+            *settings_path (str): The path of keys in your cache dictionary to get to the location desired.
+                This method assumes that the data given includes both a key and a value, and the settings
+                path leads to the *list* that the data should be cached into.
+
+        Returns:
+            typing.Callable[[discord.ext.commands.Context, typing.List[typing.Any]]]: A wrapper method
+                that does the actual work of adding data to your cache. It takes the context object from
+                the menu, and the list of returned converted arguments.
         """
 
         def wrapper(ctx, data: list):
             value = data[0]  # If we're here we definitely should only have one datapoint
-            if cls.is_discord_object(value):
+            if cls._is_discord_object(value):
                 value = value.id
             if data_location == DataLocation.GUILD:
                 d = ctx.bot.guild_settings[ctx.guild.id]
@@ -140,6 +171,20 @@ class MenuCallbacks(object):
         """
         Returns a wrapper that changes the :attr:`voxelbotutils.Bot.guild_settings` internal cache.
         Gives a nested function that takes a :code:`key` argument that acts as the primary key of the dict.
+
+        Args:
+            data_location (voxelbotutils.menus.DataLocation): The location of the content to be stored.
+            *settings_path (str): The path of keys in your cache dictionary to get to the location desired.
+                This method assumes that the settings path leads to the *dictionary* that the data
+                should be removed from the cache of.
+
+        Returns:
+            typing.Callable[[str], typing.Callable[[discord.ext.commands.Context, typing.List[typing.Any]]]]: A
+                wrapper method that does the actual work of removing data from your cache. The first wrapper takes
+                the key of the dictionary that should be removed. The second wrapper takes the context object from
+                the menu, and the list of returned converted arguments. Both wrappers are necessary as the outer wrapper
+                is used internally by the :class:`voxelbotutils.menus.MenuIterable` to make it similar to a method that
+                :class:`voxelbotutils.menus.Menu` uses.
         """
 
         def inner(key: str):
@@ -159,6 +204,20 @@ class MenuCallbacks(object):
         """
         Returns a wrapper that changes the :attr:`voxelbotutils.Bot.guild_settings` internal cache.
         Gives a nested function that takes a :code:`value` argument that acts as the data to delete.
+
+        Args:
+            data_location (voxelbotutils.menus.DataLocation): The location of the content to be stored.
+            *settings_path (str): The path of keys in your cache dictionary to get to the location desired.
+                This method assumes that the settings path leads to the *list* that the data
+                should be removed from the cache of.
+
+        Returns:
+            typing.Callable[[str], typing.Callable[[discord.ext.commands.Context, typing.List[typing.Any]]]]: A
+                wrapper method that does the actual work of removing data from your cache. The first wrapper takes
+                the value that should be removed. The second wrapper takes the context object from
+                the menu, and the list of returned converted arguments. Both wrappers are necessary as the outer wrapper
+                is used internally by the :class:`voxelbotutils.menus.MenuIterable` to make it similar to a method that
+                :class:`voxelbotutils.menus.Menu` uses.
         """
 
         def inner(value: typing.Any):
