@@ -5,7 +5,7 @@ import sys
 import typing
 import os
 import importlib
-from voxelbotutils.cogs.utils.shard_manager import ShardManager
+from voxelbotutils.cogs.utils.shard_manager import ShardManagerServer
 
 import toml
 
@@ -28,6 +28,7 @@ class CascadingLogger(logging.getLoggerClass()):
 
 
 logging.setLoggerClass(CascadingLogger)
+logger = logging.getLogger('vbu')
 
 
 # Set up the loggers
@@ -69,10 +70,6 @@ def set_log_level(
         logger_to_change.setLevel(level)
 
 
-# Set up loggers
-logger = logging.getLogger('vbu')
-
-
 # Make sure the sharding info provided is correctish
 def validate_sharding_information(args: argparse.Namespace) -> typing.Optional[typing.List[int]]:
     """
@@ -166,15 +163,11 @@ def set_default_log_levels(args: argparse.Namespace) -> None:
     formatter = logging.Formatter('{asctime} | {levelname: <8} | {name}: {message}', style='{')
     log_filter = LogFilter(logging.WARNING)
     loggers = [
-        logger,
-        DatabaseConnection.logger,
-        RedisConnection.logger,
-        StatsdConnection.logger,
+        'vbu',
         'discord',
         'aiohttp',
         'aiohttp.access',
         'upgradechat',
-        # 'shardmanager',
     ]
     for i in loggers:
         if i is None:
@@ -287,10 +280,7 @@ def run_bot(args: argparse.Namespace) -> None:
     loop = bot.loop
 
     # Set up loggers
-    bot.logger = logger
-    DatabaseConnection.logger = logger.getChild("database")
-    RedisConnection.logger = logger.getChild("redis")
-    StatsdConnection.logger = logger.getChild("statsd")
+    bot.logger = logger.getChild("bot")
     set_default_log_levels(args)
 
     # Connect the database pool
@@ -430,9 +420,6 @@ def run_website(args: argparse.Namespace) -> None:
     app['redis'] = RedisConnection
     app['logger'] = logger.getChild("route")
     app['stats'] = StatsdConnection
-    DatabaseConnection.logger = logger.getChild("database")
-    RedisConnection.logger = logger.getChild("redis")
-    StatsdConnection.logger = logger.getChild("statsd")
 
     # Add our config
     app['config'] = config
@@ -508,36 +495,16 @@ def run_sharder(args: argparse.Namespace) -> None:
 
     set_event_loop()
     loop = asyncio.get_event_loop()
-
-    # Read config
-    with open(args.config_file) as a:
-        config = toml.load(a)
-
-    RedisConnection.logger = logger.getChild("redis")
     set_default_log_levels(args)
 
-    # Connect the redis pool
-    if config.get('redis', {}).get('enabled', False):
-        re_connect = start_redis_pool(config)
-        loop.run_until_complete(re_connect)
-    else:
-        raise Exception("Redis needs to be enabled to be able to run the sharder.")
-
-    # Get the max concurrency
-    max_concurrency = loop.run_until_complete(ShardManager.get_max_concurrency(config['token']))
-
     # Run the bot
-    logger.info(f"Running sharder with {max_concurrency} shards")
-    loop.create_task(ShardManager(max_concurrency).run())
+    logger.info(f"Running sharder with {args.concurrency} shards")
+    loop.create_task(ShardManagerServer(args.host, args.port, args.concurrency).run())
     try:
         loop.run_forever()
     except KeyboardInterrupt:
         logger.info("Logging out sharder")
 
-    # We're now done running the sharder, time to clean up and close
-    logger.info("Closing redis pool")
-    RedisConnection.pool.close()
-
     logger.info("Closing asyncio loop")
     loop.stop()
     loop.close()
